%define anolis_release 2

# There are cicular build dependencies between aiohttp and gunicorn,
# Bootstraping gunicorn without tests is needed.
%bcond_without tests

%global srcname gunicorn
%global _description %{expand:
Gunicorn 'Green Unicorn' is a Python WSGI HTTP Server for UNIX. It is a
pre-fork worker model. The Gunicorn server is broadly compatible with various
web frameworks, simply implemented, light on server resources, and fairly
speedy.}

Name:           python-%{srcname}
Version:        20.1.0
Release:        %{anolis_release}%{?dist}
Summary:        Python WSGI HTTP Server
License:        MIT
URL:            https://gunicorn.org/
Source:         %pypi_source %{srcname}
# distro-specific, not upstreamable
Patch:          0001-use-dev-log-for-syslog.patch
# Patch for newer eventlet
# https://github.com/benoitc/gunicorn/commit/6a8ebb4844b2f28596ffe7421eb9f7d08c8dc4d8
Patch:          0002-eventlet-worker-ALREADY_HANDLED-WSGI_LOCAL.patch
# The following patch contains the changes from the following two upstream
# PR’s, rebased on the 20.1.0 release and combined into a single patch file.
#
#   2747-Replace pkg_resources.parse_version with packaging.version.parse
#   https://github.com/benoitc/gunicorn/pull/2958
#
#   replace pkg_resources.load_entry_point
#   https://github.com/benoitc/gunicorn/pull/2963
#
# Applying this patch eliminates a DeprecationWarning that was produced when
# importing pkg_resources (with recent setuptools versions). That warning was
# treated as an error in the tests for python-aiohttp, so this patch also
# fixes:
#
#   python-aiohttp fails to build with the latest setuptools version
#   https://bugzilla.redhat.com/show_bug.cgi?id=2183385
Patch:          gunicorn-20.1.0-remove-setuptools.patch
BuildArch:      noarch

%description %{_description}

%package -n python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel

%description -n python3-%{srcname} %{_description}

%package -n python3-%{srcname}-doc
Summary:        Documentation for the %{name} package
BuildRequires:  make

%description -n python3-%{srcname}-doc
Documentation for the %{name} package.

%prep
%autosetup -n %{srcname}-%{version} -p 1
# disable code coverage checks
sed -e '/coverage/d' -e '/pytest-cov/d' -i requirements_test.txt
%if %{without tests}
sed -e '/aiohttp/d' -i requirements_test.txt
%endif
sed -e '/addopts/d' -i setup.cfg

%generate_buildrequires
%pyproject_buildrequires requirements_dev.txt

%build
%pyproject_wheel
%make_build -C docs html

%install
%pyproject_install
%pyproject_save_files %{srcname}
# symlink extra executable names
ln -s %{_bindir}/gunicorn %{buildroot}%{_bindir}/gunicorn-3
ln -s %{_bindir}/gunicorn %{buildroot}%{_bindir}/gunicorn-%{python3_version}

%if %{with tests}
%check
%pytest --verbose tests
%endif

%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE
%{_bindir}/%{srcname}
%{_bindir}/%{srcname}-3
%{_bindir}/%{srcname}-%{python3_version}

%files -n python3-%{srcname}-doc
%doc NOTICE README.rst THANKS
%doc docs/build/html/*

%changelog
* Sun May 07 2023 Funda Wang <fundawang@yeah.net> - 20.1.0-2
- Build with tests

* Fri May 05 2023 Funda Wang <fundawang@yeah.net> - 20.1.0-1
- Import package for anolis 23
